@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from django.conf.urls.defaults import patterns, url, include
+from django.conf.urls.defaults import patterns, url
 from djangopypi.feeds import ReleaseFeed
 
 urlpatterns = patterns("djangopypi.views",
