@@ -1,17 +1,19 @@
 from django.conf import settings
 from django.http import HttpResponseNotAllowed
 
-from djangopypi.models import Package, Release
-from djangopypi.http import HttpResponseNotImplemented
+from djangopypi.decorators import csrf_exempt
 from djangopypi.http import parse_distutils_request
+from djangopypi.models import Package, Release
+from djangopypi.xmlrpc import parse_xmlrpc_request
 
-
-
+@csrf_exempt
 def root(request, fallback_view=None, **kwargs):
     """ Root view of the package index, handle incoming actions from distutils
     or redirect to a more user friendly view """
-    
+
     if request.method == 'POST':
+        if request.META['CONTENT_TYPE'] == 'text/xml':
+            return parse_xmlrpc_request(request)
         parse_distutils_request(request)
         action = request.POST.get(':action','')
     else:
